==> cloudformation-1.60.0-sources.jar: software/amazon/awscdk/services/cloudformation/CustomResourceProviderConfig.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * Configuration options for custom resource providers.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.363Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CustomResourceProviderConfig")
@software.amazon.jsii.Jsii.Proxy(CustomResourceProviderConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface CustomResourceProviderConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the SNS topic or the AWS Lambda function which implements this provider.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull java.lang.String getServiceToken();

    /**
     * @return a {@link Builder} of {@link CustomResourceProviderConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CustomResourceProviderConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<CustomResourceProviderConfig> {
        private java.lang.String serviceToken;

        /**
         * Sets the value of {@link CustomResourceProviderConfig#getServiceToken}
         * @param serviceToken The ARN of the SNS topic or the AWS Lambda function which implements this provider. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder serviceToken(java.lang.String serviceToken) {
            this.serviceToken = serviceToken;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CustomResourceProviderConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public CustomResourceProviderConfig build() {
            return new Jsii$Proxy(serviceToken);
        }
    }

    /**
     * An implementation for {@link CustomResourceProviderConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CustomResourceProviderConfig {
        private final java.lang.String serviceToken;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.serviceToken = this.jsiiGet("serviceToken", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String serviceToken) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.serviceToken = java.util.Objects.requireNonNull(serviceToken, "serviceToken is required");
        }

        @Override
        public java.lang.String getServiceToken() {
            return this.serviceToken;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("serviceToken", om.valueToTree(this.getServiceToken()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudformation.CustomResourceProviderConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CustomResourceProviderConfig.Jsii$Proxy that = (CustomResourceProviderConfig.Jsii$Proxy) o;

            return this.serviceToken.equals(that.serviceToken);
        }

        @Override
        public int hashCode() {
            int result = this.serviceToken.hashCode();
            return result;
        }
    }
}

==> cloudformation-1.104.0-sources.jar: software/amazon/awscdk/services/cloudformation/CustomResourceProviderConfig.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * (deprecated) Configuration options for custom resource providers.
 * <p>
 * @deprecated used in {@link ICustomResourceProvider} which is now deprecated
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:08.329Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CustomResourceProviderConfig")
@software.amazon.jsii.Jsii.Proxy(CustomResourceProviderConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface CustomResourceProviderConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) The ARN of the SNS topic or the AWS Lambda function which implements this provider.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull java.lang.String getServiceToken();

    /**
     * @return a {@link Builder} of {@link CustomResourceProviderConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CustomResourceProviderConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<CustomResourceProviderConfig> {
        private java.lang.String serviceToken;

        /**
         * Sets the value of {@link CustomResourceProviderConfig#getServiceToken}
         * @param serviceToken The ARN of the SNS topic or the AWS Lambda function which implements this provider. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder serviceToken(java.lang.String serviceToken) {
            this.serviceToken = serviceToken;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CustomResourceProviderConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public CustomResourceProviderConfig build() {
            return new Jsii$Proxy(serviceToken);
        }
    }

    /**
     * An implementation for {@link CustomResourceProviderConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CustomResourceProviderConfig {
        private final java.lang.String serviceToken;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.serviceToken = software.amazon.jsii.Kernel.get(this, "serviceToken", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String serviceToken) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.serviceToken = java.util.Objects.requireNonNull(serviceToken, "serviceToken is required");
        }

        @Override
        public final java.lang.String getServiceToken() {
            return this.serviceToken;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("serviceToken", om.valueToTree(this.getServiceToken()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudformation.CustomResourceProviderConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CustomResourceProviderConfig.Jsii$Proxy that = (CustomResourceProviderConfig.Jsii$Proxy) o;

            return this.serviceToken.equals(that.serviceToken);
        }

        @Override
        public final int hashCode() {
            int result = this.serviceToken.hashCode();
            return result;
        }
    }
}
